From 2c68fce2a2f340740cc3dded2c8c04841742d21a Mon Sep 17 00:00:00 2001
From: Bjarte Johansen <bjarte.johansen@gmail.com>
Date: Wed, 3 Jun 2015 12:46:32 +0200
Subject: [PATCH] ob-shell: Conform to variable assignment interface

* lisp/ob-shell.el (org-babel-shell-names):
  Initialize org-babel-variable-assignments:* for each shell.

* (org-babel-variable-assignments-bash):
  Renamed from `org-babel-variable-assignments:bash'.

* (org-babel-variable-assignments:sh):
  Apply renaming.

* testing/lisp/test-ob-shell.el
  (test-ob-shell/should-respect-ob-interface-naming-convention):
  New test.

Change org-babel-variable-assignments functions in ob-shell to use the
same function so it conforms to the interface used for variable
assignment in Org Babel.
---
 lisp/ob-shell.el              | 16 ++++++++++------
 testing/lisp/test-ob-shell.el | 11 +++++++++++
 2 files changed, 21 insertions(+), 6 deletions(-)

diff --git a/lisp/ob-shell.el b/lisp/ob-shell.el
index 5b74821..c90ba04 100644
--- a/lisp/ob-shell.el
+++ b/lisp/ob-shell.el
@@ -48,10 +48,14 @@
     (set-default symbol (second value))
     (mapc
      (lambda (name)
-       (eval `(defun ,(intern (concat "org-babel-execute:" name)) (body params)
-		,(format "Execute a block of %s commands with Babel." name)
-		(let ((shell-file-name ,name))
-		  (org-babel-execute:shell body params)))))
+       (eval
+	`(progn
+	   (defun ,(intern (concat "org-babel-execute:" name)) (body params)
+	     ,(format "Execute a block of %s commands with Babel." name)
+	     (let ((shell-file-name ,name))
+	       (org-babel-execute:shell body params)))
+	   (defvar ,(intern (concat "org-babel-variable-assignments:" name))
+	     'org-babel-variable-assignments:sh))))
      (second value))))
 
 (defun org-babel-execute:shell (body params)
@@ -121,7 +125,7 @@ This function is called by `org-babel-execute-src-block'."
      values
      "\n")))
 
-(defun org-babel-variable-assignments:bash (varname values &optional sep hline)
+(defun org-babel-variable-assignments-bash (varname values &optional sep hline)
   "Represents the parameters as useful Bash shell variables."
   (if (listp values)
       (if (and (listp (car values)) (= 1 (length (car values))))
@@ -138,7 +142,7 @@ This function is called by `org-babel-execute-src-block'."
     (mapcar
      (lambda (pair)
        (if (string-match "bash$" shell-file-name)
-	   (org-babel-variable-assignments:bash
+	   (org-babel-variable-assignments-bash
             (car pair) (cdr pair) sep hline)
          (org-babel-variable-assignments:sh-generic
 	  (car pair) (cdr pair) sep hline)))
diff --git a/testing/lisp/test-ob-shell.el b/testing/lisp/test-ob-shell.el
index 58a7859..36f0fc1 100644
--- a/testing/lisp/test-ob-shell.el
+++ b/testing/lisp/test-ob-shell.el
@@ -27,6 +27,17 @@
 (unless (featurep 'ob-shell)
   (signal 'missing-test-dependency "Support for Shell code blocks"))
 
+(ert-deftest test-ob-shell/should-respect-ob-interface-naming-convention ()
+  "Functions used to interface with the different Org Babel
+should have the correct signature."
+  (dolist (shell org-babel-shell-names)
+    (org-test-with-temp-text
+	(format "#+BEGIN_SRC<point> %s :cache yes
+  echo test
+#+END_SRC" shell)
+      (let ((info (org-babel-get-src-block-info)))
+	(should (org-babel-sha1-hash info))))))
+
 (ert-deftest test-ob-shell/dont-insert-spaces-on-expanded-bodies ()
   "Expanded shell bodies should not start with a blank line
 unless the body of the tangled block does."
-- 
2.3.2 (Apple Git-55)

